{% load i18n %}
<thead>
<tr>
  <th>{% trans "ID" %}</th>
  <th>{% trans "Date" %}</th>
  <th>{% trans "Description" %}</th>
  <th>{% trans "Invoice" %}</th>
  <th>{% trans "PDF" %}</th>
  <th>{% trans "Payee" %}</th>
  <th>{% trans "Category" %}</th>
  <th>{% trans "Type" %}</th>
  <th>{% trans "Amount (net)" %}</th>
  <th>{% trans "VAT" %}</th>
  <th>{% trans "Amount (gross)" %}</th>
  {% if show_balance %}<th>{% trans "Balance (gross)" %}</th>{% endif %}
</tr>
</thead>
