<table class="table table-hover table-condensed small">
    {% include "account_keeping/partials/transactions_table_head.html" %}
    <tbody>
    <tbody>
        {% include "account_keeping/partials/transactions_table_body.html" %}
    </tbody>
</table>
